%define fver	2.4.3

%define major		2
%define libname		%mklibname ptex %{major}
%define develname	%mklibname ptex -d
%define staticname	%mklibname ptex -s -d

Name:		ptex
Version:	%{fver}
Release:	%mkrel 3
Summary:	Per-Face Texture Mapping for Production Rendering
Group:		Graphics/3D
License:	BSD-3-Clause
URL:		https://ptex.us
Source0:	https://github.com/wdas/ptex/archive/refs/tags/v%{fver}/%{name}-%{fver}.tar.gz
Patch0:		0001-Fix-.so-version-and-major.patch
BuildRequires:	dot
BuildRequires:	doxygen
BuildRequires:	gcc-c++
BuildRequires:	cmake
BuildRequires:	pkgconfig(zlib)

%description
Ptex is a texture mapping system for production-quality rendering: no
UV assignment is required. Ptex applies a separate texture to each
face of a subdivision or polygon mesh. The Ptex file format can
efficiently store hundreds of thousands of texture images in a single
file. The Ptex API provides cached file I/O and high-quality
filtering -- everything that is needed to easily add Ptex support to a
production-quality renderer or texture authoring application.

%package -n %{libname}
Summary:	Libraries for Per-Face Texture Mapping for Rendering
Group:		System/Libraries

%description -n %{libname}
Ptex is a texture mapping system for production-quality rendering: no

This package contains the shared library of Ptex.

%package -n %{develname}
Summary:	Development files for the Ptex library
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	ptex-devel = %{version}-%{release}

%description -n %{develname}
Development files for the Ptex library.

Install this package if you plan to compile applications using the
Ptex library.

%prep
%autosetup -p1

%build
echo "v%{fver}" > version
%cmake \
	-DPTEX_BUILD_STATIC_LIBS:BOOL=ON
%cmake_build

%install
%cmake_install

# Create a pkgconfig file
%if %{mgaversion} < 10
mkdir -p %{buildroot}%{_libdir}/pkgconfig
cat <<EOF | tee %{buildroot}%{_libdir}/pkgconfig/{P,p}tex.pc
# pkg-config configuration for Ptex
prefix=%{_prefix}
libdir=%{_libdir}
includedir=%{_includedir}

Name: Ptex
Description:
Version: %{version}
Cflags: -I"\${includedir}" -pthread
Libs: -L"\${libdir}" -l:libPtex.a -lz
EOF
rm -f %{buildroot}%{_datadir}/pkgconfig/ptex.pc
%else
# Relocate .pc file
mv -f %{buildroot}%{_datadir}/pkgconfig %{buildroot}%{_libdir}
cp %{buildroot}%{_libdir}/pkgconfig/ptex.pc %{buildroot}%{_libdir}/pkgconfig/Ptex.pc
%endif


%files
%doc LICENSE README.md
%{_bindir}/*
%{_docdir}/Ptex

%files -n	%{libname}
%{_libdir}/lib*.so.%{major}{,.*}

%files -n	%{develname}
%{_includedir}/*.h
%{_libdir}/libPtex.a
%{_libdir}/libPtex.so
%{_libdir}/pkgconfig/*tex.pc
%{_libdir}/cmake/Ptex/


%changelog
* Sat Jul 12 2025 umeabot <umeabot> 2.4.3-3.mga10
+ Revision: 2253349
- Mageia 10 Mass Rebuild

* Sun Oct 20 2024 ghibo <ghibo> 2.4.3-2.mga10
+ Revision: 2108794
- Simplify SPEC file

* Sun Oct 20 2024 ghibo <ghibo> 2.4.3-1.mga10
+ Revision: 2108783
- Drop Patch merged upstream
- Update to version 2.4.3

* Sun Oct 02 2022 ghibo <ghibo> 2.4.2-1.mga9
+ Revision: 1893939
- Parallel %%ctest is broken, fix %%_smp_flags accordingly
- Update to release 2.4.2
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Thu Dec 30 2021 ghibo <ghibo> 2.4.1-1.mga9
+ Revision: 1765475
- imported package ptex


* Thu Dec 30 2021 ghibo <ghibo> 2.4.1-1.mga8
- Initial release based on internal Ptex.spec.in file
